#
# spec file for package python-wcwidth
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-wcwidth
Version:        0.1.8
Release:        lp152.3.4.1
Summary:        Number of Terminal column cells of wide-character codes
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jquast/wcwidth
Source:         https://files.pythonhosted.org/packages/source/w/wcwidth/wcwidth-%{version}.tar.gz
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This API is mainly for Terminal Emulator implementors -- any python
program that attempts to determine the printable width of a string on
a Terminal. It is implemented in python (no C library calls) and has
no 3rd-party dependencies.

It is certainly possible to use your Operating System's wcwidth(3)
and wcswidth(3) calls if it is POSIX-conforming, but this would not
be possible on non-POSIX platforms, such as Windows, or for
alternative Python implementations, such as jython.  It is also
commonly many releases older than the most current Unicode Standard
release files, which this project aims to track.

%prep
%setup -q -n wcwidth-%{version}

%build
%python_build

%install
%python_install

# Remove tests from runtime
%{python_expand rm -r %{buildroot}%{$python_sitelib}/wcwidth/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
pushd wcwidth/tests
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} test*.py
popd

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*

%changelog
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.1.8
  * Unicode v12 and proj. maintenence
  * remove static analysis
  * EastAsianWidth v9 -> v12
  * README and tox.ini
* Wed Oct  2 2019 John Vandenberg <jayvdb@gmail.com>
- Re-active test suite
- Remove test suite from runtime package
- Run fdupes
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix test macro expansion
* Thu Sep  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop devel dependency
- Install license file
* Mon Apr  3 2017 toddrme2178@gmail.com
- Fix source URL.
* Sat Apr  1 2017 toddrme2178@gmail.com
- Update to version 0.1.7
  * **Updated** tables to Unicode Specification 9.0.0. (`PR #18`_).
- Update to version 0.1.6
  0.1.6 *2016-01-08 Production/Stable*
  * ``LICENSE`` file now included with distribution.
- Update to version 0.1.5
  * **Bugfix**:
    Resolution of "combining_ character width" issue, most especially
    those that previously returned -1 now often (correctly) return 0.
    resolved by `Philip Craig`_ via `PR #11`_.
  * **Deprecated**:
    The module path ``wcwidth.table_comb`` is no longer available,
    it has been superseded by module path ``wcwidth.table_zero``.
- Implement single-spec version
* Mon Jan 30 2017 rjschwei@suse.com
- Include in SLE 12 (bsc#1002895, FATE#321630)
* Wed May  6 2015 toddrme2178@gmail.com
- Initial version
  + Version 0.1.4
